"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
async function findCluster(ecs, { family }) {
    const { clusterArns, } = await ecs.listClusters().promise();
    const clusterArnsWithTasks = await Promise.all(clusterArns.map((clusterArn) => ecs
        .listTasks({ cluster: clusterArn, family })
        .promise()
        .then(({ taskArns }) => ({
        clusterArn,
        clusterName: clusterArn.substring(clusterArn.lastIndexOf('/') + 1),
        taskArns,
    }))));
    const foundCluster = clusterArnsWithTasks.filter(({ taskArns }) => taskArns.length > 0);
    if (!foundCluster || foundCluster.length < 1) {
        throw new Error('Could not find clusters running the specified task definition family');
    }
    return foundCluster[0];
}
exports.default = findCluster;
//# sourceMappingURL=find-cluster.js.map