"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
async function setConfig(ecs, { taskDefinition: familyPrefix, key, value }) {
    const { taskDefinitionArns } = await ecs
        .listTaskDefinitions({ familyPrefix, sort: 'DESC' })
        .promise();
    if (!taskDefinitionArns || taskDefinitionArns.length === 0) {
        throw new Error('No task definitions are found');
    }
    const { taskDefinition, } = await ecs
        .describeTaskDefinition({ taskDefinition: taskDefinitionArns[0] })
        .promise();
    const { containerDefinitions, family, networkMode, volumes, placementConstraints, } = taskDefinition;
    const { taskDefinition: newTaskDefinition, } = await ecs
        .registerTaskDefinition({
        containerDefinitions: containerDefinitions.map((containerDefinition) => updateContainerDefinition(containerDefinition, key, value)),
        family: family,
        networkMode,
        placementConstraints,
        volumes,
    })
        .promise();
    return newTaskDefinition;
}
exports.default = setConfig;
function updateContainerDefinition(containerDefinition, settingKey, settingValue) {
    const { environment } = containerDefinition, rest = __rest(containerDefinition, ["environment"]);
    const envVars = new Map();
    for (const { name, value } of environment) {
        envVars.set(name, value);
    }
    envVars.set(settingKey, settingValue);
    const newEnvironment = [];
    for (const [name, value] of envVars) {
        newEnvironment.push({ name, value });
    }
    return Object.assign({ environment: newEnvironment }, rest);
}
//# sourceMappingURL=set-config.js.map