"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const find_cluster_1 = require("./find-cluster");
const list_services_1 = require("./list-services");
async function updateActiveServices(ecs, newTaskDefinition, runningServicesOnly = false) {
    const tdPrefix = newTaskDefinition.taskDefinitionArn.replace(/:\d+$/, ':');
    const { clusterArn } = await find_cluster_1.default(ecs, {
        family: newTaskDefinition.family,
    });
    const allServices = await list_services_1.default(ecs, { cluster: clusterArn });
    const activeServices = allServices.filter(({ taskDefinition, desiredCount }) => taskDefinition.startsWith(tdPrefix) &&
        (runningServicesOnly ? desiredCount > 0 : true));
    if (activeServices.length === 0) {
        throw new Error('No active services are found');
    }
    for (const { serviceName, desiredCount, deploymentConfiguration, } of activeServices) {
        await ecs
            .updateService({
            cluster: clusterArn,
            deploymentConfiguration,
            desiredCount,
            service: serviceName,
            taskDefinition: `${newTaskDefinition.family}:${newTaskDefinition.revision}`,
        })
            .promise();
    }
    return activeServices;
}
exports.default = updateActiveServices;
//# sourceMappingURL=update-active-services.js.map