"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
async function updateTaskDefinition(ecs, { taskDefinition: familyPrefix, tag }) {
    const { taskDefinitionArns } = await ecs
        .listTaskDefinitions({ familyPrefix, sort: 'DESC' })
        .promise();
    if (!taskDefinitionArns || taskDefinitionArns.length === 0) {
        throw new Error('No task definitions are found');
    }
    const { taskDefinition, } = await ecs
        .describeTaskDefinition({ taskDefinition: taskDefinitionArns[0] })
        .promise();
    const { containerDefinitions, family, networkMode, volumes, placementConstraints, } = taskDefinition;
    const newContainerDefinitions = containerDefinitions.map((containerDefinition) => (Object.assign({}, containerDefinition, { image: tag
            ? containerDefinition.image.replace(/[^:]+$/, tag)
            : containerDefinition.image })));
    const { taskDefinition: newTaskDefinition, } = await ecs
        .registerTaskDefinition({
        containerDefinitions: newContainerDefinitions,
        family: family,
        networkMode,
        placementConstraints,
        volumes,
    })
        .promise();
    return newTaskDefinition;
}
exports.default = updateTaskDefinition;
//# sourceMappingURL=update-task-definition.js.map